<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>О&#xa0;приложении </translation>
    </message>
    <message>
        <source>About</source>
        <translation>О&#xa0;приложении</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Автор</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Пожертвовать</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Контакт</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Лицензия: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Инструмент для создания и аннотирования снимков экрана</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Ярлык</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Сделать снимок экрана</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Включить курсор</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Задержка</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>с</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Режим снимка экрана</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Показать изображение в закреплённом окне</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Скопировать изображение в буфер обмена</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Выгрузить изображение на внешний ресурс</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Открыть содержащую изображение директорию</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Сохранить изображение</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Скрыть основное окно</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Настройки действий</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Требуется изображение водяного знака</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
	<translation>Пожалуйста, добавьте изображение водяного знака через Опции &gt; Настройки &gt; Параметры рисования &gt; Установить водяной знак/логотип</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Сглаживание</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>При включении сглаживает кисть
после завершения рисования.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Коэффициент</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Увеличение коэффициента сглаживания
уменьшит точность ручки и маркера,
но сделает их более плавными.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Параметры рисования</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Запомнить выбор инструмента аннотации и запустить его при загрузке</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Переключиться на выбор инструмента после рисования элемента</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Изменение нумератора обновит все нумерованные элементы</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Отключение данной опции приведёт к распространению изменений
нумератора только на новые элементы, но не на уже существующие.
Отключение опции разрешит дублирование номеров.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Цвет фона</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>Цвет фона по умолчанию для области аннотаций.
Изменение цвета повлияет только на новые аннотации.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Выбирать элемент после отрисовки</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>При включении опции элемент будет автоматически
выбираться после создания, позволяя менять параметры.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Делать скриншот при запуске</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Стиль окон</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Устанавливает стиль программы, который определяет внешний вид GUI.
Необходимо перезапустить ksnip, чтобы изменения вступили в силу.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Основные настройки</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Автоматически копировать новые скриншоты в буфер обмена</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Использовать вкладки</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Изменение требует перезапуска.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Запускать только один экземпляр ksnip</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Скрыть панель вкладок, если используется только одна вкладка.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Включение этой опции позволит запускать только один
экземпляр ksnip, все остальные запускаемые экземпляры
передадут аргументы первому. Для применения необходим
новый запуск всех экземпляров.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Запомнить положение главного окна при перемещении и восстановить при загрузке</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Автоматически скрывать вкладки</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Автоматически скрывать панели</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
	<translation>Скрывать панель инструментов и настройки аннотирования при запуске.
Видимость панелей можно переключать клавишей Tab.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Автоматически масштабировать под содержимое</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Автоматически масштабировать главное окно под размер изображения в нём.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Включить отладку</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Включает вывод отладочной информации в консоль.
Для применения необходим перезапуск ksnip.</translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation>Задержка перед масштабированием под содержимое</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>Масштабирование под содержимое выполняется с задержкой, позволяя оконному менеджеру
получить новое содержимое. Увеличение данной задержки может помочь, если главное окно
автоматически масштабируется под содержимое некорректно.</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Соавторы:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>перевод на испанский</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>перевод на нидерландский</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>перевод на русский</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>перевод на норвежский букмол</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>перевод на французский</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>перевод на польский</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Поддержка Snap и Flatpak</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>Авторы:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Внимание - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Снимок %1%2%3 был изменён.
Желаете сохранить его?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Создать</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Выделите мышкой прямоугольную область</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Сделать скриншот всего экрана со всех мониторов</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Сделать скриншот экрана, на котором расположен курсор мыши</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Сделать снимок текущего окна</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Сделать скриншот окна, на котором расположен курсор мыши</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Сделать скриншот последней выделенной области</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Использовать screenshot Portal для снимков экрана</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Сообщество</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Сообщения об ошибках</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Присоединяйтесь к нашим %1 или %2 серверам,&lt;br/&gt; если у вас есть вопросы, идеи, или просто хотите обсудить ksnip.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Используйте, пожалуйста, %1 для сообщений об ошибках.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Не удалось скопировать в буфер обмена</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Не удалось скопировать изображение в буфер обмена в виде base64-кода.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Скопировано в буфер обмена</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Изображение скопировано в буфер обмена в виде base64-кода.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Удалить изображение</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Элемент &quot;%1&quot; будет удален.
Согласны продолжить?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Пожертвования всегда приветствуются</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Пожертвование</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip&amp;nbsp;&amp;mdash; это некоммерческий проект с открытым исходным кодом, но&lt;br/&gt;проект всё равно требует покрытия некоторых затрат,&lt;br/&gt;таких как оплата домена или инструментов кросс-платформенной поддержки.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Если вы хотите помочь или просто хотите оценить проделанную работу,&lt;br/&gt;угостив разработчиков пивом или кофе, можете сделать это %1здесь%2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>Стать спонсором на GitHub?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Также можете, %1здесь%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Добавьте новые действия нажатием на вкладке кнопки «Добавить».</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Прямоугольная область</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Последняя прямоугольная область</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Полноэкранный режим (все мониторы)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Текущий экран</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Активное окно</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Окно под курсором мыши</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Портал скриншота</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Анонимная выгрузка.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>Выгрузка на FTP</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Успешно выгружено</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Не удалось сохранить временное изображение для выгрузки.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Не удалось запустить процесс, проверьте путь и права доступа.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Процесс аварийно завершился</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Время процесса истекло.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Ошибка чтения процесса.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Ошибка записи процесса.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
	<translation>Ошибка сети, проверьте вывод консоли.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Выгрузка не удалась</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Скрипт написал в стандартный вывод ошибок.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>Выгрузка на FTP-сервер успешно завершена.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Неизвестная ошибка.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Ошибка подключения.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Ошибка прав доступа.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>Скрипт выгрузки %1 завершился успешно.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Выгружено на %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Включить горячие клавиши (эта функция не работает в Wayland)</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Снимок выделенной области</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Снимок всего экрана</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Снимок текущего экрана</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Снимок активного окна</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
	<translation>Снимок окна под курсором мыши</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Горячие клавиши</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Снимок последней области</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Захват с помощью портала</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Горячие клавиши поддерживаются только в Windows и X11.
При отключении данной опции сочетания клавиш будут работать только в ksnip.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
	<translation>Показывать курсор мыши на снимке экрана</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Должен ли быть виден курсор мыши
во время снимка экрана.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Настройки захвата</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Общие реализации Wayland, использующие
XDG-DESKTOP-PORTAL, реализуют масштабирование
по-разному. Включение этой опции приведет к
определению масштаба текущего экрана и
применению его к скриншоту в ksnip.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME и KDE Plasma поддерживают собственные методы получения
скриншотов в Wayland и базовый метод через XDG-DESKTOP-PORTAL.
Включение этой опции заставит KDE Plasma и GNOME
использовать базовый метод XDG-DESKTOP-PORTAL.
Изменение этого параметра требует перезапуска ksnip.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
	<translation>Показать главное окно после выполнения снимка экрана</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Скрыть главное окно во время снимка экрана</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Скрыть главное окно при захвате нового снимка экрана.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Показать основное окно после выполенения снимка,
если оно было скрыто или свёрнуто.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Использовать для получения скриншота в Wayland базовый метод (xdg-desktop-portal)</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Масштабировать скриншоты, полученные базовым методом Wayland (xdg-desktop-portal)</translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>История Imgur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Ссылка</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Ссылка на удаление</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Выгрузка на imgur.com завершена!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Получен новый токен, повторная попытка выгрузки…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Срок действия токена истек, запрашивается новый токен…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Форсировать анонимную выгрузку</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Копировать ссылку в буфер обмена</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>ID клиента</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Секретный ключ клиента</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN-код</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Введите PIN-код с Imgur, который будет заменен на токен.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Получить PIN</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Получить токен</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>История Imgur</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Выгрузка на Imgur</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Ожидание imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur.com: токен был обновлен.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Imgur.com: ошибка во время обновления токена.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>После выгрузки открыть ссылку Imgur в браузере по умолчанию</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Прямая ссылка на изображение</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Базовый URL:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Базовый URL, используемый для связи с Imgur.
Изменение потребует перезапуска.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Очистить токен</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Невозможно открыть изображение</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>Невозможно открыть изображение %1</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Создать</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Задержка в секундах перед тем,
как будет сделан снимок экрана.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>с</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
	<translation>Сохранить снимок экрана в файловой системе</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
	<translation>Копировать снимок экрана в буфер обмена</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Вернуть</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Обрезать</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
	<translation>Обрезать снимок экрана</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Не сохранено</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Выгрузить на внешний ресурс</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Печать</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Открывает диалоговое окно принтера для предоставления опций печати</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Предпросмотр печати</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Открыть предварительный просмотр распечатки, в котором можно изменить ориентацию изображения</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Изменить размер</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О приложении</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Редактировать</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Опции</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>Add Watermark</source>
	<translation>Добавить водяной знак/логотип</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Добавить водянной знак/логотип. Можно добавить несколько.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Невозможно показать изображение</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Сохранить как…</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Вставить интегрированным</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Закрепить</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
	<translation>Закрепить снимок экрана на переднем плане в безрамочном окне</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Никакого изображения не было, но его ожидали увидеть.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Скопировать путь</translation>
    </message>
    <message>
        <source>Open Directory</source>
	<translation>Открыть папку с файлом</translation>
    </message>
    <message>
        <source>&amp;View</source>
	<translation>&amp;Просмотр</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Открытое изображение</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Показать панели</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Скрыть панели</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Скопировать в виде «data: URI»</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
	<translation>&amp;Последние файлы</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Изменить фон</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
	<translation>Передать снимок экрана на внешний ресурс</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Скопировать снимок в системный буфер обмена</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Масштабировать изображение</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Повернуть</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Повернуть изображение</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Файлы изображений</translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Открыть расположение</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Скопировать путь</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Снимок</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Закрыть остальные</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрыть все</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Закрепить окно %1</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>Изображение переименовано</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Не удалось переименовать изображение</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Переименовать изображение</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Новое имя файла:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>Изображение успешно переименовано в %1</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>Не удалось переименовать изображение в %1</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Все файлы</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Изображение сохранено</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Ошибка во время сохранения изображения</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Файлы изображений</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Сохранено в %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>Не удалось сохранить изображение в %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Автоматически сохранять новые снимки в папку по умолчанию</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Выводить диалог сохранения изменений перед отменой</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Запоминать последнюю папку для сохранения</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>При включении каждый раз будет перезаписываться путь 
для сохранения, указанный в настройках, на последний используемый.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Место сохранения снимков и название файла</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Поддерживаемые форматы: JPG, PNG и BMP. Если формат не указан, будет выбран PNG как по умолчанию.
Имя файла может содержать следующие подстановочные знаки:
- $Y, $M, $D для даты, $h, $m, $s для времени, или $T для времени в формате hhmmss.
- Используйте многократно # для счётчиков. #### приведет к результату 0001, следующий снимок будет 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Настройки сохранения</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Место сохранения снимка</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Уровень</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Качество сохранения</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Укажите 0 для наибольшего сжатия, 100 для больших файлов с наилучшим качеством.
Не все форматы изображений поддерживают полный диапазон, но JPEG поддерживает.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Копировать вывод скрипта в буфер обмена</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Скрипт:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Путь к скрипту, вызываемому для выгрузки. В процессе выгрузки скрипт будет вызван
с путём к временному PNG-файлу, в качестве единственного аргумента.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Обзор</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Выгрузка через скрипт</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Выбрать скрипт выгрузки</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Остановить, если скрипт выгрузки напишет в стандартный поток ошибок</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Отметит выгрузку как неудачную, если скрипт напишет в стандартный поток ошибок.
Без этой опции ошибки скрипта будут проигнорированы.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Фильтр:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>Регулярное выражение. В буфер обмена будет скопировано только то, что удовлетворяет этому выражению.
Если не задано, будет скопировано всё.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Захват изображения</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Выгрузка на Imgur</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Приложение</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Параметры рисования</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Горячие клавиши</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Выгрузка</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Выгрузка через скрипт</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Сохранение</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Стикеры</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Зона обрезки</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Значок в трее</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Водяной знак</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP-загрузчик</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Масштабируйте прямоугольник выделения, используя маркеры, или двигайте его, перетаскивая выделенную обрасть.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Используйте клавиши-стрелки для перемещения выделенной области.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Удерживая Ctrl, используйте клавиши-стрелки для перемещения левого верхнего маркера.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Удерживая Alt, используйте клавиши-стрелки для перемещения правого нижнего маркера.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation>Подтвердите выделение нажатием клавиши Enter или отмените действие нажатием Escape.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Это сообщение может быть отключено через настройки.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Нажмите и перемещайте для выбора прямоугольной области, или нажмите ESC для выхода.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Зажмите CTRL для изменения размера после выбора зоны.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Оставляйте CTRL нажатым для отключения режима редактирования зоны после выбора.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>Операция будет отменена через 60 секунд, если не будет сделано выбора.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Это сообщение может быть отключено через настройки.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Заблокировать выделенную область при снимке</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>При включении - блокирует задний фон от изменений
в процессе выделения области захвата. 
Также меняет поведение снимков экрана с задержкой, 
при включенной опции - задержка
включается до захвата области 
выбора, при выключенной - после.
Эта опция всегда отключена для Wayland
и всегда включена для MacOs.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Показывать лупу во время выделения</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Показывает лупу во время выделения области.
Эта опция работает только при включенной
опции «Заморозить выделенную область».</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Показывать линии для зоны выделения</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Показывает горизонтальные и вертикальные пунктирные
линии от краёв экрана к зоне выделения.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Показывать координаты и размер зоны</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Если левая кнопка мыши не нажата - положение
отображается, при нажатии кнопки мыши
размер выбранной области отображается в 
левом верхнему углу захватываемой зоны.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Разрешить изменение размера выделения по умолчанию</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Позволяет изменить вручную размеры зоны
после выделения. Для подтверждения 
изменённых размеров необходимо нажать
кнопку Enter.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Показывать подсказки в зоне скриншота</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Цвет курсора зоны скриншота</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Задаёт цвет курсора для выбора области обрезки.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Толщина курсора области обрезки</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Задаёт толщину курсора области обрезки.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Зона обрезки</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Цвет декорирования зоны обрезки</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Задаёт цвет всех декоративных
элементов зоны обрезки.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Прозрачность зоны обрезки</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>Прозрачность невыделенной области в зоне обрезки
Меньше значение — больше прозрачность.</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Вверх</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Использовать стикеры по умолчанию</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Настройки стикеров</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Файлы векторных изображений (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Add Stickers</source>
	<translation>Добавить стикеры</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Показать редактор</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Показывать значок в трее</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>При включении добавит значок в трей (системный лоток панели задач), если оконный менеджер ОС поддерживает это.
Изменение требует перезапуска приложения.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Сворачивать в трей</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Запускать свёрнутым в трей</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Сворачивать в трей при закрытии</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Показать редактор</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Снимок</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Действие по умолчанию для значка в трее</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>Действие по умолчанию, вызываемое нажатием левой кнопкой мыши на значок в трее.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Настройки значка в трее</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Использовать системную службу уведомлений</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>При включении будет использоваться системная служба уведомлений,
если таковая существует. Для изменения необходим перезапуск.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Отображать уведомления значка в системном лотке</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Выбрать изображение</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Файлы изображений</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Необходим скрипт выгрузки</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Пожалуйста добавьте скрипт выгрузки через Опции → Настройки → Выгрузка → Выгрузка через скрипт → Скрипт</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Выгрузка снимка экрана на внешний ресурс</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Вы собираетесь выгрузить изображение на внешний ресурс, хотите продолжить?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Запрашивать подтверждение перед выгрузкой</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Тип выгрузки:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Скрипт</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Выгрузка на внешний ресурс</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Сборка</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Программа использует:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Водяной знак</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Повернуть водяной знак</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>При включении водяной знак будет добавлен повёрнутым на 45°</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Настройки водяного знака</translation>
    </message>
</context>
</TS>
